summaryrefslogtreecommitdiffstats
path: root/microbe/btreenode.h
diff options
context:
space:
mode:
Diffstat (limited to 'microbe/btreenode.h')
-rw-r--r--microbe/btreenode.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/microbe/btreenode.h b/microbe/btreenode.h
index 7f5fdfb..2594d0c 100644
--- a/microbe/btreenode.h
+++ b/microbe/btreenode.h
@@ -24,8 +24,8 @@
#include "btreebase.h"
#include "expression.h"
-#include <qstring.h>
-#include <qptrlist.h>
+#include <tqstring.h>
+#include <tqptrlist.h>
/**
A node points to the two child nodes (left and right), and contains the binary
@@ -46,13 +46,13 @@ class BTreeNode
*/
// void printTree();
/**
- * Recursively delete all children of a node.
+ * Recursively delete all tqchildren of a node.
*/
void deleteChildren();
/**
* @return the parent node.
*/
- BTreeNode *parent() const { return m_parent; }
+ BTreeNode *tqparent() const { return m_parent; }
/**
* @return the left child node.
*/
@@ -61,7 +61,7 @@ class BTreeNode
* @return the right child node.
*/
BTreeNode *right() const { return m_right; }
- void setParent(BTreeNode *parent) { m_parent = parent; }
+ void setParent(BTreeNode *tqparent) { m_parent = tqparent; }
/**
* Set the child node on the left to the one give, and reparents it to
* this node.
@@ -79,14 +79,14 @@ class BTreeNode
ExprType type() const {return m_type;}
void setType(ExprType type) { m_type = type; }
- QString value() const {return m_value;}
- void setValue( const QString & value ) { m_value = value; }
+ TQString value() const {return m_value;}
+ void setValue( const TQString & value ) { m_value = value; }
Expression::Operation childOp() const {return m_childOp;}
void setChildOp(Expression::Operation op){ m_childOp = op;}
- void setReg( const QString & r ){ m_reg = r; }
- QString reg() const {return m_reg;}
+ void setReg( const TQString & r ){ m_reg = r; }
+ TQString reg() const {return m_reg;}
bool needsEvaluating() const { return hasChildren(); }
@@ -96,10 +96,10 @@ class BTreeNode
BTreeNode *m_right;
/** This is used to remember what working register contains the value of the node during assembly.*/
- QString m_reg;
+ TQString m_reg;
ExprType m_type;
- QString m_value;
+ TQString m_value;
Expression::Operation m_childOp;
};
@@ -46,13 +46,13 @@ class BTreeNode
void deleteChildren();
/**
- * @return the parent node.
+ * @return the tqparent node.
*/